tempotools.rewrite_duration_under_new_tempo
===========================================

.. autofunction:: abjad.tools.tempotools.rewrite_duration_under_new_tempo.rewrite_duration_under_new_tempo
   :noindex:
